==> torque-4.0-source-release.zip: torque-4.0/torque-test/src/test/java/org/apache/torque/datatypes/VarbinaryTest.java <==
package org.apache.torque.datatypes;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.torque.test.dbobject.VarbinaryType;
import org.apache.torque.test.peer.VarbinaryTypePeer;

public class VarbinaryTest extends ByteTypeTest<VarbinaryType>
{

    public VarbinaryTest() {
        super(VarbinaryTypePeer.getVarbinaryTypePeerImpl(),
                new VarbinaryType());
    }

    @Override
    protected void setBytes(byte[] bytes, VarbinaryType toFill)
    {
        toFill.setVarbinaryValue(bytes);
        toFill.setVarbinaryObjectValue(bytes);
    }

    @Override
    protected byte[] getBytes(VarbinaryType toRead)
    {
        return toRead.getVarbinaryValue();
    }

    @Override
    public int getByteArraySize() {
        return 100;
    }
}

==> torque-5.0-source-release.zip: torque-5.0/torque-test/src/test/java/org/apache/torque/datatypes/VarbinaryTest.java <==
package org.apache.torque.datatypes;

import org.apache.torque.adapter.Adapter;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.torque.test.dbobject.VarbinaryType;
import org.apache.torque.test.peer.VarbinaryTypePeer;

public class VarbinaryTest extends ByteTypeTest<VarbinaryType>
{

    public VarbinaryTest() {
        super(VarbinaryTypePeer.getVarbinaryTypePeerImpl(),
                new VarbinaryType());
    }

    @Override
    protected void setBytes(byte[] bytes, VarbinaryType toFill)
    {
        toFill.setVarbinaryValue(bytes);
        toFill.setVarbinaryObjectValue(bytes);
    }

    @Override
    protected byte[] getBytes(VarbinaryType toRead)
    {
        return toRead.getVarbinaryValue();
    }

    @Override
    public int getByteArraySize(Adapter adapter) {
        return 100;
    }
}
